@@ -4,38 +4,22 @@ Astro::Coord::ECI::Star - Compute the position of a star.
 
 =head1 SYNOPSIS
 
- use Astro::Coord::ECI;
- use Astro::Coord::ECI::Star;
- use Astro::Coord::ECI::Utils qw{deg2rad};
- 
- # 1600 Pennsylvania Ave, Washington DC USA
- # latitude 38.899 N, longitude 77.038 W,
- # altitude 16.68 meters above sea level
- my $lat = deg2rad (38.899);    # Radians
- my $long = deg2rad (-77.038);  # Radians
- my $alt = 16.68 / 1000;        # Kilometers
- 
- my $star = Astro::Coord::ECI::Star->new (
-     name => 'Spica')->position(
-     3.51331869544372,    # Right ascension, radians
-     -0.194802985206623,  # Declination, radians
- );
- my $sta = Astro::Coord::ECI->
-     universal (time ())->
-     geodetic ($lat, $long, $alt);
+ my $star = Astro::Coord::ECI::Star->star ();
+ my $sta = Astro::Coord::ECI->new (name => 'Spica')->
+     position (3.51331869544372, -0.194802985206623);
  my ($time, $rise) = $sta->next_elevation ($star);
- print "Star @{[$rise ? 'rise' : 'set']} is ",
-     scalar localtime $time, "\n";
+ print "Spica's @{[$rise ? 'rise' : 'set']} is ",
+     scalar localtime $time;
 
 =head1 DESCRIPTION
 
 This module implements the position of a star (or any other object
 which can be regarded as fixed on the celestial sphere) as a function
 of time, as described in Jean Meeus' "Astronomical Algorithms," second
-edition. It is a subclass of L<Astro::Coord::ECI|Astro::Coord::ECI>,
-with a position() method to set the catalog position (and optionally
-proper motion as well), and the time_set() method overridden to compute
-the position of the star at the given time.
+edition. It is a subclass of B<Astro::Coord::ECI>, with a position()
+method to set the catalog position (and optionally proper motion as
+well), and the time_set() method overridden to compute the position
+of the star at the given time.
 
 =head2 Methods
 
@@ -45,17 +29,23 @@ The following methods should be considered public:
 
 =cut
 
-package Astro::Coord::ECI::Star;
-
 use strict;
 use warnings;
 
-our $VERSION = '0.133_01';
+package Astro::Coord::ECI::Star;
+
+our $VERSION = '0.004';
 
 use base qw{Astro::Coord::ECI};
 
-use Astro::Coord::ECI::Utils qw{ @CARP_NOT :mainstream };
+use Astro::Coord::ECI::Sun;	# Need for abberation calc.
+use Astro::Coord::ECI::Utils qw{:all};
 use Carp;
+use Data::Dumper;
+use POSIX qw{floor strftime};
+##use Time::Local;
+use UNIVERSAL qw{isa};
+
 
 =item $star = Astro::Coord::ECI::Star->new();
 
@@ -74,22 +64,17 @@ worked example is in equatorial coordinates.
 =cut
 
 sub new {
-    my ($class, @args) = @_;
-    ref $class and $class = ref $class;
-    return $class->SUPER::new (angularvelocity => 0,
-	@args);
+my $class = shift;
+my $self = $class->SUPER::new (angularvelocity => 0,
+    @_);
 }
 
-=item @almanac = $star->almanac($station, $start, $end);
 
-This method produces almanac data for the star for the given observing
-station, between the given start and end times. The station is assumed
-to be Earth-Fixed - that is, you can not do this for something in orbit.
+=item @almanac = $star->almanac($location, $start, $end);
 
-The C<$station> argument may be omitted if the C<station> attribute has
-been set. That is, this method can also be called as
-
- @almanac = $star->almanac( $start, $end )
+This method produces almanac data for the star for the given location,
+between the given start and end times. The location is assumed to be
+Earth-Fixed - that is, you can not do this for something in orbit.
 
 The start time defaults to the current time setting of the $star
 object, and the end time defaults to a day after the start time.
@@ -112,50 +97,39 @@ potentially returned:
 
 =cut
 
-sub __almanac_event_type_iterator {
-    my ( $self, $station ) = @_;
+sub almanac {
+my $self = shift;
+my $location = shift;
+ref $location && UNIVERSAL::isa ($location, 'Astro::Coord::ECI') or
+    croak <<eod;
+Error - The first argument of the almanac() method must be a member of
+        the Astro::Coord::ECI class, or a subclass thereof.
+eod
 
-    my $inx = 0;
+my $start = shift || $self->universal;
+my $end = shift || $start + 86400;
 
-    my $horizon = $station->__get_almanac_horizon();
+my @almanac;
 
-    my @events = (
-	[ $station, next_elevation => [ $self, $horizon, 1 ],
-	    horizon => '__horizon_name' ],
-	[ $station, next_meridian => [ $self ],
-	    transit => '__transit_name' ],
-    );
-
-    return sub {
-	$inx < @events
-	    and return @{ $events[$inx++] };
-	return;
-    };
+my $name = $self->get ('name') || $self->get ('id') || 'star';
+foreach (
+	[$location, next_elevation => [$self, 0, 1], 'horizon',
+		["$name sets", "$name rises"]],
+	[$location, next_meridian => [$self], 'transit',
+		[undef, "$name transits meridian"]],
+	) {
+    my ($obj, $method, $arg, $event, $descr) = @$_;
+    $obj->universal ($start);
+    while (1) {
+	my ($time, $which) = $obj->$method (@$arg);
+	last unless $time && $time < $end;
+	push @almanac, [$time, $event, $which, $descr->[$which]]
+	    if $descr->[$which];
+	}
+    }
+return sort {$a->[0] <=> $b->[0]} @almanac;
 }
 
-use Astro::Coord::ECI::Mixin qw{ almanac };
-
-=item @almanac = $star->almanac_hash($station, $start, $end);
-
-This convenience method wraps $star->almanac(), but returns a list of
-hash references, sort of like Astro::Coord::ECI::TLE->pass()
-does. The hashes contain the following keys:
-
-  {almanac} => {
-    {event} => the event type;
-    {detail} => the event detail (typically 0 or 1);
-    {description} => the event description;
-  }
-  {body} => the original object ($star);
-  {station} => the observing station;
-  {time} => the time the quarter occurred.
-
-The {time}, {event}, {detail}, and {description} keys correspond to
-elements 0 through 3 of the list returned by almanac().
-
-=cut
-
-use Astro::Coord::ECI::Mixin qw{ almanac_hash };
 
 use constant NEVER_PASS_ELEV => 2 * __PACKAGE__->SECSPERDAY;
 
@@ -189,8 +163,9 @@ position of the star in question.
 =cut
 
 sub position {
-    my ($self, @args) = @_;
-    return @{$self->{_star_position}} unless @args;
+    my $self = shift;
+    return @{$self->{_star_position}} unless @_;
+    my @args = @_;
     $args[2] ||= PARSEC;
     @args < 5 and splice @args, 3, 0, 0, 0, 0;
     $args[3] ||= 0;
@@ -202,7 +177,7 @@ sub position {
     # CAVEAT: time_set() picks the equinox directly out of the above
     # hash.
     $self->dynamical ($args[6]);
-    return $self;
+    $self;
 }
 
 =item $star->time_set()
@@ -219,38 +194,35 @@ time is set.
 The computation comes from Jean Meeus' "Astronomical Algorithms", 2nd
 Edition, Chapter 23, pages 149ff.
 
-B<Note>, however, that for consistency with the
-L<Astro::Coord::ECI::Sun|Astro::Coord::ECI::Sun> and
-L<Astro::Coord::ECI::Moon|Astro::Coord::ECI::Moon> classes, the position
-is precessed to the current time setting.
+B<Note>, however, that for consistency with the Astro::Coord::ECI::Sun
+and ::Moon classes, the position is precessed to the current time
+setting.
 
 =cut
 
 use constant CONSTANT_OF_ABERRATION => deg2rad (20.49552 / 3600);
 
 sub time_set {
-    my $self = shift;
+my $self = shift;
 
-    $self->{_star_position} or croak <<eod;
+$self->{_star_position} or croak <<eod;
 Error - The position of the star has not been set.
 eod
 
-    my ($ra, $dec, $range, $mra, $mdc, $mrg, $epoch) = @{
-	$self->{_star_position}};
+my ($ra, $dec, $range, $mra, $mdc, $mrg, $epoch) = @{$self->{_star_position}};
 
-    my $time = $self->universal;
-    my $end = $self->dynamical;
+my $time = $self->universal;
+my $end = $self->dynamical;
 
 #	Account for the proper motion of the star, and set our
 #	equatorial coordinates to the result.
 
-    my $deltat = $end - $epoch;
-    #### $ra += $mra * $deltat;
-    $ra = mod2pi($ra + $mra * $deltat);
-    $dec += $mdc * $deltat;
-    $range += $mrg * $deltat;
-    ##!! $self->set (equinox => $epoch);
-    $self->equatorial ($ra, $dec, $range);
+my $deltat = $end - $epoch;
+$ra += $mra * $deltat;
+$dec += $mdc * $deltat;
+$range += $mrg * $deltat;
+##!! $self->set (equinox => $epoch);
+$self->equatorial ($ra, $dec, $range);
 
 #	NOTE: The call to precess() used to be here. I have no idea why,
 #	other than that I thought I could go back and forth between
@@ -264,41 +236,43 @@ eod
 
 #	Get ecliptic coordinates, and correct for nutation.
 
-    my ($beta, $lambda) = $self->ecliptic ();
-    my ( $delta_psi ) = $self->nutation();
-    $lambda += $delta_psi;
+my ($beta, $lambda) = $self->ecliptic ();
+my $delta_psi = nutation_in_longitude ($self->dynamical);
+$lambda += $delta_psi;
 
-#	Calculate and add in the aberration terms (Meeus 23.2);
 
-    my $T = jcent2000 ($time);			# Meeus (22.1)
-    my $e = (-0.0000001267 * $T - 0.000042037) * $T + 0.016708634;# Meeus (25.4)
-    my $pi = deg2rad ((0.00046 * $T + 1.71946) * $T + 102.93735);
-    my $sun = $self->get( 'sun' );
-    $sun->universal ($time);
+#	Calculate and add in the abberation terms (Meeus 23.2);
 
-    my $geoterm = $sun->geometric_longitude () - $lambda;
-    my $periterm = $pi - $lambda;
-    my $deltalamda = ($e * cos ($periterm) - cos ($geoterm)) *
-	    CONSTANT_OF_ABERRATION / cos ($beta);
-    my $deltabeta = - (sin ($geoterm) - $e * sin ($periterm)) * sin ($beta) *
-	    CONSTANT_OF_ABERRATION;
-    $lambda += $deltalamda;
-    $beta += $deltabeta;
+my $T = jcent2000 ($time);			# Meeus (22.1)
+my $e = (-0.0000001267 * $T - 0.000042037) * $T + 0.016708634;	# Meeus (25.4)
+my $pi = deg2rad ((0.00046 * $T + 1.71946) * $T + 102.93735);
+my $sun = $self->{_star_sun} ||= Astro::Coord::ECI::Sun->new ();
+$sun->universal ($time);
 
-    $self->ecliptic ($beta, $lambda, $range);
+my $geoterm = $sun->geometric_longitude () - $lambda;
+my $periterm = $pi - $lambda;
+my $deltalamda = ($e * cos ($periterm) - cos ($geoterm)) *
+	CONSTANT_OF_ABERRATION / cos ($beta);
+my $deltabeta = - (sin ($geoterm) - $e * sin ($periterm)) * sin ($beta) *
+	CONSTANT_OF_ABERRATION;
+$lambda += $deltalamda;
+$beta += $deltabeta;
+
+$self->ecliptic ($beta, $lambda, $range);
 
 #	Set the equinox to that implied when our position was set.
 
-    ## $self->set (equinox_dynamical => $epoch);
-    $self->equinox_dynamical ($epoch);
+## $self->set (equinox_dynamical => $epoch);
+$self->equinox_dynamical ($epoch);
 
 #	Precess ourselves to the current equinox.
 
-    $self->precess_dynamical ($end);
+$self->precess_dynamical ($end);
 
-    return $self;
+$self;
 }
 
+
 1;
 
 =back
@@ -310,43 +284,33 @@ Algorithms" (second edition) formed the basis for this module.
 
 =head1 SEE ALSO
 
-The L<Astro::Coord::ECI::OVERVIEW|Astro::Coord::ECI::OVERVIEW>
-documentation for a discussion of how the pieces/parts of this
-distribution go together and how to use them.
-
-L<Astro::Catalog|Astro::Catalog> by Alasdair Allan, which accommodates a
+The B<Astro-Catalog> package by Alasdair Allan, which accommodates a
 much more fulsome description of a star. The star's coordinates are
 represented by an B<Astro::Coords> object.
 
-L<Astro::Coords|Astro::Coords> by Tim Jenness can also be used to find
+The B<Astro-Coords> package by Tim Jenness can also be used to find
 the position of a star at a given time given a catalog entry for the
 star. A wide variety of coordinate representations is accommodated.
 This package requires B<Astro::SLA>, which in its turn requires the
 SLALIB library.
 
-=head1 SUPPORT
-
-Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-satpass>,
-L<https://github.com/trwyant/perl-Astro-Coord-ECI/issues>, or in
-electronic mail to the author.
-
 =head1 AUTHOR
 
 Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT
 
-Copyright (C) 2005-2025 by Thomas R. Wyant, III
+Copyright 2005, 2006, 2007 by Thomas R. Wyant, III
+(F<wyant at cpan dot org>). All rights reserved.
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl 5.10.0. For more details, see the full text
-of the licenses in the directory LICENSES.
+=head1 LICENSE
 
-This program is distributed in the hope that it will be useful, but
-without any warranty; without even the implied warranty of
-merchantability or fitness for a particular purpose.
+This module is free software; you can use it, redistribute it
+and/or modify it under the same terms as Perl itself. Please see
+L<http://perldoc.perl.org/index-licence.html> for the current licenses.
+
+This software is provided without any warranty of any kind, express or
+implied. The author will not be liable for any damages of any sort
+relating in any way to this software.
 
 =cut
-
-# ex: set textwidth=72 :
